
#ifndef INCLUDED_MULTIDISPLAY_H
#define INCLUDED_MULTIDISPLAY_H

//###########################################################################
//############################### INCLUDES ##################################
//###########################################################################

#include <windows.h>

#if defined(__cplusplus)
extern "C"
{
#endif

#define MD_DISPLAY_LCD     1
#define MD_DISPLAY_TV      2
#define MD_DISPLAY_CRT     4
#define MD_DISPLAY_HDMI    8

#define MD_DISPLAYMODE_FLAGS_NATIVE 2

#define MD_MODE_FLAGS_CHECKEDID 1

typedef struct mdDisplayModeRec {
    DWORD       Width;              /*!< Width in pixels. */
    DWORD       Height;             /*!< Height in pixels. */
    DWORD       BitsPerPixel;       /*!< Total bits used to describe a color. */
    DWORD       RefreshRate;        /*!< Screen refresh rate in Hz. */
    DWORD       Flags;              /*!< See enum ::NvDispMgrDisplayModeFlags. */
} mdDisplayMode;

// Open Client Handle to Multidisplay manager
DWORD mdOpen(HANDLE *pmdHandle);

// Close Client Handle to Multidisplay manager
DWORD mdClose(HANDLE mdHandle);

// Get a Mask of all Active Displays
DWORD mdDisplayGetActive(HANDLE mdHandle, DWORD *pDisplayMask);

// List Display Modes of Displays selected with DisplayMask
// pModes: pointer that will receive an array of mdDisplayMode
// nModes: On input specifies the max no of modes, on output it tells the actual number modes
// Flags: Can be MD_MODE_FLAGS_CHECKEDID if a actual check of the display supported resolutions should be made, otherwise a static list is returned
// NOTE: if pModes is NULL, pnModes will return the number of modes
DWORD mdDisplayListModes(HANDLE mdHandle, DWORD DisplayMask, mdDisplayMode *pModes, DWORD nModes, DWORD Flags);

// Activate Display for DisplayMask
// pMode: specifies display mode to change to (NULL for native display mode)
// bgColor: Color used as a background for parts not covered by the overlay
DWORD mdDisplayActivate(HANDLE mdHandle, DWORD DisplayMask, mdDisplayMode *pMode, DWORD bgColor);

// Returns the current display mode for DisplayMask
DWORD mdDisplayGetCurrentMode(HANDLE mdHandle, DWORD DisplayMask, mdDisplayMode *pMode);

// Deactivates Display/s identified by DisplayMask
DWORD mdDisplayDeactivate(HANDLE mdHandle, DWORD DisplayMask);

// Creates an Overlay
// DisplayMask: Specifies on which displays the overlay should be exclusive (all other overlays will be hidden)
DWORD mdOverlayCreate(HANDLE mdHandle, DWORD DisplayMask, HANDLE *phOverlay);

// Sets the rect of the Overlay
DWORD mdOverlaySetRect(HANDLE mdHandle, DWORD DisplayMask, HANDLE hOverlay, RECT *rect);

// Sets the Rotation of the Overlay
DWORD mdOverlaySetRotation(HANDLE mdHandle, DWORD DisplayMask, HANDLE hOverlay, DWORD angle);

// Sets the Alpha level and depth of the Overlay
// alpha: 0..255 (0=transparent 255=opaque)
// depth: 0 is frontmost
DWORD mdOverlaySetAlpha(HANDLE mdHandle, DWORD DisplayMask, HANDLE hOverlay, DWORD alpha, DWORD depth);

// Unreferences/ Destroys the Overlay
DWORD mdOverlayUnref(HANDLE mdHandle, HANDLE hOverlay);


#if defined(__cplusplus)
}
#endif

#endif  // INCLUDED_MULTIDISPLAY_H